@@ -63,7 +63,8 @@ public:
            std::string fontname_symbol_,
            bool editable_, int id_,
            std::string raster_prefix_,
-           int next_rels_id_, int standalone_):
+           int next_rels_id_, int standalone_,
+           double width_, double height_ ):
       filename(filename_),
       pageno(0),
 	    id(id_),
@@ -77,6 +78,10 @@ public:
       cc(gdtools::context_create()){
 
     file = fopen(R_ExpandFileName(filename.c_str()), "w");
+    clipleft = 0.0;
+    clipright = width_;
+    cliptop = 0.0;
+    clipbottom = height_;
     clp = new clipper();
   }
 
@@ -259,7 +264,7 @@ static void docx_line(double x1, double y1, double x2, double y2,
   std::vector<NumericVector> x_array = docx_obj->clp->get_x_lines();
   std::vector<NumericVector> y_array = docx_obj->clp->get_y_lines();
 
-  for( int l = 0 ; l < x_array.size() ; l++ ){
+  for( size_t l = 0 ; l < x_array.size() ; l++ ){
     docx_do_polyline(x_array.at(l), y_array.at(l), gc, dd);
   }
 
@@ -283,7 +288,7 @@ static void docx_polyline(int n, double *x, double *y, const pGEcontext gc,
   std::vector<NumericVector> x_array = docx_obj->clp->get_x_lines();
   std::vector<NumericVector> y_array = docx_obj->clp->get_y_lines();
 
-  for( int l = 0 ; l < x_array.size() ; l++ ){
+  for( size_t l = 0 ; l < x_array.size() ; l++ ){
     docx_do_polyline(x_array.at(l), y_array.at(l), gc, dd);
   }
 
@@ -580,7 +585,8 @@ pDevDesc docx_driver_new(std::string filename, int bg, double width, double heig
     fontname_serif, fontname_sans, fontname_mono, fontname_symbol,
     editable, id,
     raster_prefix,
-    next_rels_id, standalone);
+    next_rels_id, standalone,
+    width * 72, height * 72);
   return dd;
 }
 
