@@ -46,3 +46,27 @@ test_that("check pptx editable properties", {
   xpath_ <- ".//p:sp/p:nvSpPr/p:cNvSpPr/a:spLocks"
   expect_error(object = xml_find_one(x, xpath_, ns = xml_ns( x )), regexp = "No matches")
 })
+
+
+test_that("check xlsx editable properties", {
+
+  file <- tempfile()
+  dml_xlsx( file = file, editable = FALSE, bg = "transparent" )
+  plot.new()
+  points(0.2, 0.2)
+  dev.off()
+
+  x <- read_xml(file)
+  xpath_ <- ".//xdr:sp/xdr:nvSpPr/xdr:cNvSpPr/a:spLocks"
+  node <- try( xml_find_one(x, xpath_, ns = xml_ns( x )), silent = TRUE )
+  expect_is(object = node, class = "xml_node")
+
+  file <- tempfile()
+  dml_xlsx( file = file, editable = TRUE, bg = "transparent" )
+  plot.new()
+  points(0.2, 0.2)
+  dev.off()
+  x <- read_xml(file)
+  xpath_ <- ".//xdr:sp/xdr:nvSpPr/xdr:cNvSpPr/a:spLocks"
+  expect_error(object = xml_find_one(x, xpath_, ns = xml_ns( x )), regexp = "No matches")
+})
